package Koha::AdditionalFields;

=head1 NAME

Koha::AdditionalFields - Koha::Objects derived class for additional fields

=cut

use Modern::Perl;

use base 'Koha::Objects';

use Koha::AdditionalField;

sub _type { 'AdditionalField' }

=head2 object_class

Missing POD for object_class.

=cut

sub object_class { 'Koha::AdditionalField' }

=head1 AUTHOR

Koha Development Team <https://koha-community.org/>

=head1 COPYRIGHT AND LICENSE

Copyright 2018 BibLibre

This file is part of Koha.

Koha is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

Koha is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with Koha; if not, see <https://www.gnu.org/licenses>.

=head1 SEE ALSO

L<Koha::Objects>

=cut

1;
